# Glulx

The Glulx specification was written by Andrew Plotkin as an attempt to define a format for interactive fiction games that the Inform compiler could compile to, without the limitations of its original output format, Infocom's Z-Machine.

Windows Git is based on Iain Merrick's Git 1.3.5, which is a complete implementation of version 3.1.2 of the Glulx specification.

More information on Glulx is available from the Glulx web page: http://www.eblong.com/zarf/glulx/